@@ -37,11 +37,14 @@ typedef struct _Dimension {
     int height;
 } Dimension;
 
+enum State {
+    StateStart = 0, StatePlaying, StateStop, StateTerminate
+};
+
 static Display             *display;
 static Window               wid;
 static gboolean             window_created = TRUE;
 static gboolean             verbose;
-static gboolean             notified_playing;
 static int                  movie_width;
 static int                  movie_height;
 static int                  movie_length;
@@ -65,6 +68,7 @@ static guint                position_tag;
 static int                  seek_start;
 static guint                current_volume;
 static gboolean             has_video_codec;
+static enum State           current_state;
 
 static gboolean cb_play (gpointer data);
 static gboolean cb_buffering (gpointer data);
@@ -308,8 +312,9 @@ static void gstBusMessage (GstBus *bus, GstMessage *message, gpointer data) {
                     gchar *name = gst_object_get_name (GST_OBJECT (message->src));
                     fprintf (stderr, "%s changed to PLAYING\n", name);
                     if (!has_video_codec && !strcmp (name, "videosink")) {
+                        GstPad *pad;
                         has_video_codec = TRUE;
-                        GstPad *pad = gst_element_get_static_pad (
+                        pad = gst_element_get_static_pad (
                                 GST_ELEMENT (message->src), "sink");
                         if (!pad)
                             pad = gst_element_get_request_pad (
@@ -455,7 +460,6 @@ static void play () {
         }
         return;
     }
-    notified_playing = FALSE;
     if (!mrl || !mrl[0])
         return;
     movie_length = movie_width = movie_height = 0;
@@ -576,10 +580,9 @@ static void pause () {
 }
 
 static void stop () {
-    static gboolean entered;
-    if (entered)
+    if (current_state >= StateStop)
         return;
-    entered = TRUE;
+    current_state = StateStop;
     fprintf (stderr, "stop %s\n", !mrl || !mrl[0] ? "<empty>" : mrl);
     if (position_tag) {
         g_source_remove (position_tag);
@@ -596,7 +599,6 @@ static void stop () {
         gst_element_get_state (gst_elm_play, NULL, NULL, -1);
     }
     g_idle_add (cb_finished, NULL);
-    entered = FALSE;
 }
 
 /*static void finished () {
@@ -633,11 +635,12 @@ static void brightness (int b) {
     adjustColorSetting ("BRIGHTNESS", b);
 } */
 
-static void seek (int val /*offset_in_deciseconds*/) {
+static void seek (int val /*offset_in_deciseconds*/, int abs) {
     if (gst_elm_play)
         gst_element_seek (gst_elm_play, 1.0, GST_FORMAT_TIME,
                 (GstSeekFlags) (GST_SEEK_FLAG_FLUSH | GST_SEEK_FLAG_KEY_UNIT),
-                GST_SEEK_TYPE_SET, val * GST_MSECOND * 100,
+                abs ? GST_SEEK_TYPE_SET : GST_SEEK_TYPE_CUR,
+                val * GST_MSECOND * 100,
                 GST_SEEK_TYPE_NONE, GST_CLOCK_TIME_NONE);
 }
 
@@ -719,26 +722,31 @@ static gboolean cb_play (gpointer data) {
 static gboolean cb_buffering (gpointer data) {
     GstState state;
     (void)data;
-    gst_element_get_state (gst_elm_play, &state, NULL, 0);
-    if (state != GST_STATE_PLAYING)
-        output ("\rCache fill: %d%", (long) data);
+
+    if (current_state < StateStop) {
+        gst_element_get_state (gst_elm_play, &state, NULL, 0);
+        if (state != GST_STATE_PLAYING)
+            output ("\rCache fill: %d%", (long) data);
+    }
     return FALSE;
 }
 
 static gboolean cb_playing (gpointer data) {
     (void)data;
-    if (!notified_playing) {
-        notified_playing = TRUE;
-        if (!has_video_codec)
-            output ("Video: no video\n");
-        output ("\rA:0.0\rA:0.0");
-        if (seek_start > 0)
-            seek (seek_start * 10);
-    } else {
-        output ("\rCache fill: 100%");
+    if (current_state < StateStop) {
+        if (current_state < StatePlaying) {
+            current_state = StatePlaying;
+            if (!has_video_codec)
+                output ("Video: no video\n");
+            output ("\rA:0.0\rA:0.0");
+            if (seek_start > 0)
+                seek (seek_start * 10, 1);
+        } else {
+            output ("\rCache fill: 100%");
+        }
+        if (!position_tag)
+            position_tag = g_timeout_add (500, cb_position, NULL);
     }
-    if (!position_tag)
-        position_tag = g_timeout_add (500, cb_position, NULL);
     return FALSE;
 }
 
@@ -796,6 +804,9 @@ static gboolean cb_error (gpointer data) {
 
 static gboolean cb_finished (gpointer data) {
     (void)data;
+    if (current_state >= StateTerminate)
+        return FALSE;
+    current_state = StateTerminate;
     if (gst_elm_play) {
         gst_bus_set_flushing (gst_bus, TRUE);
         if (gst_bus_sync)
@@ -859,7 +870,7 @@ static gboolean watchStdin (GIOChannel *src, GIOCondition cond, gpointer data) {
                         if (!strncmp (cmdbuf, "seek ", 5)) {
                             int nr = sscanf (cmdbuf + 5, "%d %d", &d1, &d2);
                             if (nr > 1)
-                                seek (10 * d1);
+                                seek (10 * d1, d2);
                         } else if (!strncmp (cmdbuf, "volume ", 7)) {
                             int nr = sscanf (cmdbuf + 7, "%d", &d1);
                             if (nr > 0)
