@@ -129,6 +129,8 @@ void cb_playlist_play (GtkButton * button, void *ctr);
 void cb_playlist_next (GtkButton * button, void *ctr);
 void cb_playlist_stop (GtkButton * button, void *ctr);
 gboolean playlist_selected (Application *app, GValue *icon, GValue *text);
+void collapseSelectedList (Application *app);
+void expandSelectedList (Application *app);
 void cb_favorites_add (Application *app);
 void progressValueChanged(GtkWidget *w, Application * app);
 gboolean cb_scheduledPaint (void * p);
