@@ -67,6 +67,14 @@ void FileDocument::writeToFile (const String & fn) {
     file.writeBlock (utf, strlen (utf));
 }
 
+void FileDocument::sync (const String &fn)
+{
+    if (resolved && load_tree_version != m_tree_version) {
+        writeToFile (fn);
+        load_tree_version = m_tree_version;
+    }
+}
+
 KDE_NO_CDTOR_EXPORT Recents::Recents (Application *a)
     : FileDocument (id_node_recent_document, "recents://"),
       app(a) {
@@ -122,12 +130,12 @@ KDE_NO_EXPORT void Recent::activate () {
     String pos = getAttribute ("clipBegin");
     if (!pos.isEmpty ())
         doc->clip_begin = parseTimeString (pos);
-    CONTROL(app)->openDocument (doc, NULL);
+    CONTROL(app)->openDocument (doc, doc);
 }
 
 KDE_NO_CDTOR_EXPORT
 Group::Group (KMPlayer::NodePtr & doc, Application * a, const String & pn)
-  : KMPlayer::Title (doc, KMPlayer::id_node_group_node), app (a) {
+  : Element (doc, KMPlayer::id_node_group_node), app (a) {
     title = pn;
     if (!pn.isEmpty ())
         setAttribute (KMPlayer::StringPool::attr_title, pn);
@@ -146,7 +154,14 @@ KDE_NO_EXPORT KMPlayer::Node *Group::childFromTag (const String & tag) {
 KDE_NO_EXPORT void Group::closed () {
     if (title.isEmpty ())
         title = getAttribute (KMPlayer::StringPool::attr_title);
-    KMPlayer::Title::closed ();
+    Element::closed ();
+}
+
+void *Group::role (KMPlayer::RoleType msg, void *content)
+{
+    if (KMPlayer::RolePlaylist == msg)
+        return (KMPlayer::PlaylistRole *) this ;
+    return Element::role (msg, content);
 }
 
 // gconftool -s -t string /apps/maemo/kmplayer/playlist_file /home/koos/playlist.xml
@@ -202,7 +217,8 @@ KDE_NO_EXPORT void PlaylistItemBase::activate () {
     if (playmode) {
         Mrl::activate ();
     } else {
-        NodePtr pl = new Playlist (app, CONTROL(app), true);
+        Playlist *pl = new Playlist (app, CONTROL(app), true);
+        KMPlayer::NodePtr n = pl;
         String data;
         String pn;
         if (parentNode ()->id == KMPlayer::id_node_group_node &&
@@ -210,7 +226,7 @@ KDE_NO_EXPORT void PlaylistItemBase::activate () {
             data = String ("<playlist>") +
                 parentNode ()->innerXML () +
                 String ("</playlist>");
-            pn = parentNode ()->caption ();
+            pn = ((PlaylistRole *)parentNode ()->role (RolePlaylist))->caption ();
         } else {
             data = outerXML ();
             pn = title.isEmpty () ? src : title;
@@ -258,8 +274,8 @@ KDE_NO_EXPORT void PlaylistItem::begin () {
 }
 
 KDE_NO_CDTOR_EXPORT
-PlaylistGroup::PlaylistGroup (KMPlayer::NodePtr & doc, Application * a, const String & pn)
- : KMPlayer::Title (doc, KMPlayer::id_node_group_node),
+PlaylistGroup::PlaylistGroup (NodePtr & doc, Application * a, const String & pn)
+ : Element (doc, KMPlayer::id_node_group_node),
    app (a),
    playmode (false) {
     title = pn;
@@ -268,8 +284,8 @@ PlaylistGroup::PlaylistGroup (KMPlayer::NodePtr & doc, Application * a, const St
 }
 
 KDE_NO_CDTOR_EXPORT
-PlaylistGroup::PlaylistGroup (KMPlayer::NodePtr & doc, Application * a, bool lm)
- : KMPlayer::Title (doc, KMPlayer::id_node_group_node),
+PlaylistGroup::PlaylistGroup (NodePtr & doc, Application * a, bool lm)
+ : Element (doc, KMPlayer::id_node_group_node),
    app (a),
    playmode (lm) {
 }
@@ -288,7 +304,14 @@ KDE_NO_EXPORT KMPlayer::Node *PlaylistGroup::childFromTag (const String & tag) {
 KDE_NO_EXPORT void PlaylistGroup::closed () {
     if (title.isEmpty ())
         title = getAttribute (KMPlayer::StringPool::attr_title);
-    KMPlayer::Title::closed ();
+    Element::closed ();
+}
+
+void *PlaylistGroup::role (KMPlayer::RoleType msg, void *content)
+{
+    if (KMPlayer::RolePlaylist == msg)
+        return (KMPlayer::PlaylistRole *) this ;
+    return Element::role (msg, content);
 }
 
 KDE_NO_CDTOR_EXPORT
