@@ -276,7 +276,7 @@ public:
     void activate ();
     void deactivate ();
     void closed ();
-    bool expose () const;
+    void *role (RoleType msg, void *content=NULL);
     void message (MessageType msg, void *content=NULL);
     void accept (Visitor *v) { v->visit (this); }
     void jump (const String & id);
@@ -297,7 +297,6 @@ public:
     KDE_NO_EXPORT const char * nodeName () const { return "head"; }
     void closed ();
     void message (MessageType msg, void *content=NULL);
-    bool expose () const;
 };
 
 /**
@@ -317,7 +316,6 @@ public:
     virtual void message (MessageType msg, void *content=NULL);
     virtual void *role (RoleType msg, void *content=NULL);
     KDE_NO_EXPORT virtual const char * nodeName () const { return "state"; }
-    virtual bool expose () const { return false; }
 
     void newValue (Node *ref, Where w, const String &name, const String &val);
     void setValue (Node *ref, const String &value);
@@ -339,7 +337,6 @@ public:
     void closed ();
     void message (MessageType msg, void *content=NULL);
     void accept (Visitor *v) { v->visit (this); }
-    bool expose () const { return false; }
 
     NodePtrW root_layout;
 };
@@ -352,7 +349,6 @@ public:
     enum ShowBackground { ShowAlways, ShowWhenActive };
 
     ~RegionBase ();
-    virtual bool expose () const { return false; }
     virtual void activate ();
     virtual void deactivate ();
     virtual void parseParam (const TrieString & name, const String & value);
@@ -424,7 +420,6 @@ public:
     KDE_NO_CDTOR_EXPORT RegPoint (NodePtr & d) : Element(d, id_node_regpoint) {}
     ~RegPoint () {}
     KDE_NO_EXPORT const char * nodeName () const { return "regPoint"; }
-    KDE_NO_EXPORT bool expose () const { return false; }
     void parseParam (const TrieString & name, const String & value);
     CalculatedSizer sizes;
 };
@@ -468,7 +463,6 @@ public:
     KDE_NO_EXPORT void accept (Visitor * v) { v->visit (this); }
     KDE_NO_EXPORT const char * nodeName () const { return "transition"; }
     void parseParam (const TrieString & name, const String & value);
-    KDE_NO_EXPORT bool expose () const { return false; }
     bool supported ();
     TransType type;
     TransSubType sub_type;
@@ -493,7 +487,6 @@ public:
     void activate ();
     void deactivate ();
     void reset ();
-    bool expose () const { return false; }
     void message (MessageType msg, void *content=NULL);
     void *role (RoleType msg, void *content=NULL);
     void setJumpNode (NodePtr);
@@ -612,7 +605,6 @@ class KMPLAYER_NO_EXPORT LinkingBase : public Element {
 public:
     KDE_NO_CDTOR_EXPORT ~LinkingBase () {}
     void deactivate ();
-    KDE_NO_EXPORT bool expose () const { return false; }
     void parseParam (const TrieString & name, const String & value);
     ConnectionLink mediatype_attach;
     String href;
@@ -673,7 +665,6 @@ public:
     virtual void message (MessageType msg, void *content=NULL);
     virtual void *role (RoleType msg, void *content=NULL);
     virtual void accept (Visitor *v) { v->visit (this); }
-    bool expose () const { return false; }
 
     Surface *surface ();
 
@@ -720,7 +711,7 @@ public:
     virtual void begin ();
     virtual void finish ();
     virtual void accept (Visitor *);
-    virtual bool expose () const;
+    virtual void *role (RoleType msg, void *content=NULL);
     virtual void prefetch ();
     virtual void clipStart ();
 };
@@ -769,7 +760,6 @@ public:
     virtual void finish ();
     virtual void deactivate ();
     virtual void reset ();
-    virtual bool expose () const { return false; }
     KDE_NO_EXPORT const char *nodeName () const { return "smilText"; }
     Node *childFromTag (const String & tag);
     virtual void parseParam (const TrieString &name, const String &value);
@@ -795,7 +785,6 @@ public:
 
     virtual void init ();
     virtual void activate ();
-    virtual bool expose () const { return false; }
     KDE_NO_EXPORT const char *nodeName () const { return (const char *) tag; }
     Node *childFromTag (const String &tag);
     virtual void parseParam (const TrieString &name, const String &value);
@@ -817,7 +806,6 @@ public:
     virtual void parseParam (const TrieString &name, const String &value);
     virtual void message (MessageType msg, void *content=NULL);
     virtual void *role (RoleType msg, void *content=NULL);
-    virtual bool expose () const { return false; }
 protected:
     StateValue (NodePtr &d, short _id);
 
@@ -865,7 +853,6 @@ public:
     virtual void finish ();
     virtual void deactivate ();
     virtual void reset ();
-    virtual bool expose () const { return false; }
     virtual void parseParam (const TrieString & name, const String & value);
     virtual void message (MessageType msg, void *content=NULL);
     virtual void *role (RoleType msg, void *content=NULL);
@@ -1017,7 +1004,6 @@ public:
     KDE_NO_CDTOR_EXPORT Param (NodePtr & d) : Element (d, id_node_param) {}
     KDE_NO_EXPORT const char * nodeName () const { return "param"; }
     void activate ();
-    bool expose () const { return false; }
 };
 
 } // SMIL namespace
