@@ -365,6 +365,13 @@ void Control::play () {
     }
 }
 
+static PlayListData *playListData (PlayListData *pld, short id)
+{
+    while (pld->id != id)
+        pld = pld->next;
+    return pld;
+}
+
 void Control::stop (bool keep_fullscreen) {
     back_request = 0L;
     if (playlist_data->document &&
@@ -412,7 +419,9 @@ void Control::stop (bool keep_fullscreen) {
         }
         if (ts != nts) {
             recent_mrl->setAttribute ("clipBegin", nts);
-            recents->document ()->m_tree_version++;
+            playListData (playlist_data, m_app->recents_tree_id)
+                ->updated_document_version =
+                    ++recents->document ()->m_tree_version;
         }
     }
     m_process->quit ();
@@ -863,6 +872,7 @@ void Control::addRecent (const String &url, const String &title) {
             if (count > 50)
                 more->removeChild (more->lastChild ());
         }
+        playListData(playlist_data, m_app->recents_tree_id)->current = NULL;
         updateTree (m_app, m_app->recents_tree_id);
     }
 }
