@@ -176,7 +176,7 @@ void ConnectionList::clear () {
 
 KDE_NO_CDTOR_EXPORT Node::Node (NodePtr & d, short _id)
  : m_doc (d), state (state_init), id (_id),
-   auxiliary_node (false), editable (true), open (false) {}
+   auxiliary_node (false), open (false) {}
 
 Node::~Node () {
     clear ();
@@ -912,7 +912,6 @@ Document::Document (const String & s, PlayListNotify * n)
     src = s;
     if (!s.isEmpty ())
         setAttribute (StringPool::attr_src, s);
-    editable = false;
 }
 
 Document::~Document () {
