@@ -420,10 +420,6 @@ public:
     bool isPlayable () { return playType () > play_type_none; }
     virtual bool isElementNode () const { return false; }
     virtual String description () const;
-    /**
-     * If this node should be visible to the user
-     */
-    bool isEditable () const { return editable; }
     /**
      * If this node purpose is for storing runtime data only,
      * ie. node doesn't exist in the original document
@@ -517,7 +513,6 @@ public:
     State state;
     short id;
     bool auxiliary_node : 1;
-    bool editable : 1;
     bool open : 1;
 };
 
