@@ -103,7 +103,8 @@ int populate (GtkTreeStore * tree_store, PlayListData * pld,
     GtkTreeIter iter, citer, cciter;
     bool m_have_dark_nodes = false;
     int child_count = 0;
-    if (!pld->show_all && !e->role (RolePlaylist) && piter) {
+    PlaylistRole *title = (PlaylistRole *) e->role (RolePlaylist);
+    if (!pld->show_all && !title && piter) {
         if (pld->current.ptr () == e)
             *fpath = gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), piter);
         for (Node *c = e->firstChild (); c; c = c->nextSibling ())
@@ -114,7 +115,6 @@ int populate (GtkTreeStore * tree_store, PlayListData * pld,
         gtk_tree_store_append (tree_store, &iter, piter);
     else
         iter = *riter;
-    PlaylistRole *title = (PlaylistRole *) e->role (RolePlaylist);
     String text (title ? title->caption () : "");
     if (text.isEmpty ()) {
         Mrl *mrl = e->mrl ();
@@ -168,15 +168,15 @@ int populate (GtkTreeStore * tree_store, PlayListData * pld,
     g_value_unset (&value);
 }*/
 
-static gboolean findFirstExposed (Node *node, bool recursive)
+static int countFirstExposed (Node *node, bool recursive)
 {
     if (node->role (RolePlaylist))
-        return true;
+        return 1;
+    int nr = 0;
     if (recursive)
         for (Node *c = node->firstChild (); c; c = c->nextSibling ())
-            if (findFirstExposed (c, true))
-                return true;
-    return false;
+            nr += countFirstExposed (c, true);
+    return nr;
 }
 
 static gboolean findNodeImpl (PlayListData *pld, GtkTreeModel *model, Node *node, GtkTreeIter *iter, bool &expand) {
@@ -185,8 +185,8 @@ static gboolean findNodeImpl (PlayListData *pld, GtkTreeModel *model, Node *node
         if (!findNodeImpl (pld, model, p, iter, expand))
             return false;
         for (Node *n = p->firstChild (); n; n = n->nextSibling ()) {
-            bool expose = pld->show_all || findFirstExposed (n, n != node);
-            if (expose) {
+            int exposed = pld->show_all ? 1 : countFirstExposed (n, n != node);
+            for (int i = exposed; i > 0; --i) {
                 if (expand) {
                     expand = false;
                     GtkTreeIter piter = *iter;
@@ -201,7 +201,7 @@ static gboolean findNodeImpl (PlayListData *pld, GtkTreeModel *model, Node *node
                 }
             }
             if (n == node) {
-                if (expose)
+                if (exposed)
                     expand = true;
                 return true;
             }
@@ -285,6 +285,8 @@ void KMPlayer::updateTree (Application * app, short id) {
         if (pld->current &&
                 findNode (pld, model, pld->current.ptr (), &riter))
             fpath = gtk_tree_model_get_path (model, &riter);
+        else
+            gtk_tree_selection_unselect_all (gtk_tree_view_get_selection (treeview));
 
     } else {
 
